@@ -140,12 +140,12 @@ func Test_GetRequiredUpdates(t *testing.T) {
 			Name: "kube-system",
 		},
 	}
-	fakek8s := fakekubernetes.NewSimpleClientset(kubeSystem)
+	fakek8s := fakekubernetes.NewClientset(kubeSystem)
 	fakecm := fakecertmanager.NewSimpleClientset()
 	addon := &Addon{
 		Name: "test",
 		Spec: &api.AddonSpec{
-			Name:     fi.String("test"),
+			Name:     fi.PtrTo("test"),
 			NeedsPKI: true,
 		},
 	}
@@ -173,9 +173,9 @@ func Test_NeedsRollingUpdate(t *testing.T) {
 			newAddon: &Addon{
 				Name: "test",
 				Spec: &api.AddonSpec{
-					Name:               fi.String("test"),
+					Name:               fi.PtrTo("test"),
 					ManifestHash:       "originalHash",
-					NeedsRollingUpdate: "all",
+					NeedsRollingUpdate: api.NeedsRollingUpdateAll,
 				},
 			},
 		},
@@ -183,9 +183,9 @@ func Test_NeedsRollingUpdate(t *testing.T) {
 			newAddon: &Addon{
 				Name: "test",
 				Spec: &api.AddonSpec{
-					Name:               fi.String("test"),
+					Name:               fi.PtrTo("test"),
 					ManifestHash:       "newHash",
-					NeedsRollingUpdate: "all",
+					NeedsRollingUpdate: api.NeedsRollingUpdateAll,
 				},
 			},
 			updateRequired:      true,
@@ -195,9 +195,9 @@ func Test_NeedsRollingUpdate(t *testing.T) {
 			newAddon: &Addon{
 				Name: "test",
 				Spec: &api.AddonSpec{
-					Name:               fi.String("test"),
+					Name:               fi.PtrTo("test"),
 					ManifestHash:       "newHash",
-					NeedsRollingUpdate: "worker",
+					NeedsRollingUpdate: api.NeedsRollingUpdateWorkers,
 				},
 			},
 			updateRequired:      true,
@@ -207,9 +207,9 @@ func Test_NeedsRollingUpdate(t *testing.T) {
 			newAddon: &Addon{
 				Name: "test",
 				Spec: &api.AddonSpec{
-					Name:               fi.String("test"),
+					Name:               fi.PtrTo("test"),
 					ManifestHash:       "newHash",
-					NeedsRollingUpdate: "control-plane",
+					NeedsRollingUpdate: api.NeedsRollingUpdateControlPlane,
 				},
 			},
 			updateRequired:      true,
@@ -219,9 +219,9 @@ func Test_NeedsRollingUpdate(t *testing.T) {
 			newAddon: &Addon{
 				Name: "test",
 				Spec: &api.AddonSpec{
-					Name:               fi.String("test"),
+					Name:               fi.PtrTo("test"),
 					ManifestHash:       "newHash",
-					NeedsRollingUpdate: "all",
+					NeedsRollingUpdate: api.NeedsRollingUpdateAll,
 				},
 			},
 			originalAnnotations: map[string]string{
@@ -271,7 +271,7 @@ func Test_NeedsRollingUpdate(t *testing.T) {
 
 		existingChannels := FindChannelVersions(kubeSystem)
 
-		fakek8s := fakekubernetes.NewSimpleClientset(objects...)
+		fakek8s := fakekubernetes.NewClientset(objects...)
 		fakecm := fakecertmanager.NewSimpleClientset()
 
 		addon := g.newAddon
@@ -333,12 +333,12 @@ func Test_InstallPKI(t *testing.T) {
 			Name: "kube-system",
 		},
 	}
-	fakek8s := fakekubernetes.NewSimpleClientset(kubeSystem)
+	fakek8s := fakekubernetes.NewClientset(kubeSystem)
 	fakecm := fakecertmanager.NewSimpleClientset()
 	addon := &Addon{
 		Name: "test",
 		Spec: &api.AddonSpec{
-			Name:     fi.String("test"),
+			Name:     fi.PtrTo("test"),
 			NeedsPKI: true,
 		},
 	}
