@@ -16,7 +16,7 @@ limitations under the License.
 
 package mockec2
 
-import "github.com/aws/aws-sdk-go/aws"
+import "github.com/aws/aws-sdk-go-v2/aws"
 
 // s is a helper that builds a *string from a string value
 func s(v string) *string {
