@@ -58,16 +58,17 @@ func (m *MockClient) mockZones() {
 		zoneName = r.Form.Get("name")
 		switch r.Method {
 		case http.MethodGet:
-			if zoneID == "" && zoneName == "" {
+			switch {
+			case zoneID == "" && zoneName == "":
 				// /zones
 				m.listZones(w)
-			} else if len(parts) == 3 && parts[2] == "recordsets" {
+			case len(parts) == 3 && parts[2] == "recordsets":
 				// /zones/<zoneid>/recordsets
 				m.listRecordSets(w, zoneID)
-			} else if len(parts) == 4 && parts[2] == "recordsets" {
+			case len(parts) == 4 && parts[2] == "recordsets":
 				// /zones/<zoneid>/recordsets/<recordsetid>
 				m.getRecordSet(w, zoneID, parts[3])
-			} else {
+			default:
 				// /zones?name=<zonename>
 				m.getZone(w, zoneName)
 			}
