@@ -223,7 +223,6 @@ const (
 	scwCSIAddon = "scaleway-csi-driver.addons.k8s.io-k8s-1.24"
 
 	calicoAddon  = "networking.projectcalico.org-k8s-1.25"
-	canalAddon   = "networking.projectcalico.org.canal-k8s-1.25"
 	ciliumAddon  = "networking.cilium.io-k8s-1.16"
 	flannelAddon = "networking.flannel-k8s-1.25"
 	kindnetAddon = "networking.kindnet-k8s-1.32"
@@ -246,28 +245,6 @@ func TestMinimalAWS(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
-// TestMinimal runs the test on a minimum configuration
-func TestMinimal_v1_27(t *testing.T) {
-	newIntegrationTest("minimal.example.com", "minimal-1.27").
-		withAddons(
-			awsEBSCSIAddon,
-			dnsControllerAddon,
-			awsCCMAddon,
-		).
-		runTestTerraformAWS(t)
-}
-
-// TestMinimal runs the test on a minimum configuration
-func TestMinimal_v1_28(t *testing.T) {
-	newIntegrationTest("minimal.example.com", "minimal-1.28").
-		withAddons(
-			awsEBSCSIAddon,
-			dnsControllerAddon,
-			awsCCMAddon,
-		).
-		runTestTerraformAWS(t)
-}
-
 // TestMinimal runs the test on a minimum configuration
 func TestMinimal_v1_29(t *testing.T) {
 	newIntegrationTest("minimal.example.com", "minimal-1.29").
@@ -722,15 +699,6 @@ func TestPrivateCiliumENI(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
-// TestPrivateCanal runs the test on a configuration with private topology, canal networking
-func TestPrivateCanal(t *testing.T) {
-	newIntegrationTest("privatecanal.example.com", "privatecanal").
-		withPrivate().
-		withDefaultAddons30().
-		withAddons(canalAddon).
-		runTestTerraformAWS(t)
-}
-
 const kopeioNetworkingAddon = "networking.kope.io-k8s-1.12"
 
 // TestPrivateKopeio runs the test on a configuration with private topology, kopeio networking
@@ -945,11 +913,11 @@ func TestKarpenter(t *testing.T) {
 		withOIDCDiscovery().
 		withDefaults24().
 		withAddons("karpenter.sh-k8s-1.19").
-		withServiceAccountRole("aws-node-termination-handler.kube-system", true).
+		withoutNTH().
 		withServiceAccountRole("karpenter.kube-system", true)
 	test.expectTerraformFilenames = append(test.expectTerraformFilenames,
-		"aws_launch_template_karpenter-nodes-single-machinetype.minimal.example.com_user_data",
-		"aws_launch_template_karpenter-nodes-default.minimal.example.com_user_data",
+		"aws_s3_object_nodeupscript-karpenter-nodes-single-machinetype_content",
+		"aws_s3_object_nodeupscript-karpenter-nodes-default_content",
 		"aws_s3_object_nodeupconfig-karpenter-nodes-single-machinetype_content",
 		"aws_s3_object_nodeupconfig-karpenter-nodes-default_content",
 	)
@@ -1605,7 +1573,7 @@ func (i *integrationTest) runTestTerraformAWS(t *testing.T) {
 			"aws_cloudwatch_event_rule_" + awsup.GetClusterName40(i.clusterName) + "-SpotInterruption_event_pattern",
 			"aws_cloudwatch_event_rule_" + awsup.GetClusterName40(i.clusterName) + "-InstanceStateChange_event_pattern",
 			"aws_cloudwatch_event_rule_" + awsup.GetClusterName40(i.clusterName) + "-InstanceScheduledChange_event_pattern",
-			"aws_sqs_queue_" + strings.Replace(i.clusterName, ".", "-", -1) + "-nth_policy",
+			"aws_sqs_queue_" + strings.ReplaceAll(i.clusterName, ".", "-") + "-nth_policy",
 		}...)
 	}
 	if i.nthRebalance {
@@ -1633,7 +1601,8 @@ func (i *integrationTest) runTestPhase(t *testing.T, phase cloudup.Phase) {
 
 	expectedFilenames := i.expectTerraformFilenames
 
-	if phase == cloudup.PhaseSecurity {
+	switch phase {
+	case cloudup.PhaseSecurity:
 		expectedFilenames = []string{
 			"aws_iam_role_masters." + i.clusterName + "_policy",
 			"aws_iam_role_nodes." + i.clusterName + "_policy",
@@ -1648,7 +1617,7 @@ func (i *integrationTest) runTestPhase(t *testing.T, phase cloudup.Phase) {
 				"aws_launch_template_bastion." + i.clusterName + "_user_data",
 			}...)
 		}
-	} else if phase == cloudup.PhaseCluster {
+	case cloudup.PhaseCluster:
 		expectedFilenames = []string{
 			"aws_launch_template_nodes." + i.clusterName + "_user_data",
 		}
