@@ -359,9 +359,9 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 	if !c.IgnoreKubeletVersionSkew {
 		minControlPlaneRunningVersion, err = checkControlPlaneRunningVersion(ctx, cluster.ObjectMeta.Name, minControlPlaneRunningVersion)
 		if err != nil {
-			klog.Warningf("error checking control plane running version, assuming no k8s upgrade in progress: %v", err)
+			klog.V(2).Infof("error checking control plane running version, assuming no k8s upgrade in progress: %v", err)
 		} else {
-			klog.V(2).Infof("successfully checked control plane running version: %v", minControlPlaneRunningVersion)
+			klog.V(2).Infof("found control plane running version: %v", minControlPlaneRunningVersion)
 		}
 	}
 	applyCmd := &cloudup.ApplyClusterCmd{
@@ -412,6 +412,10 @@ func RunUpdateCluster(ctx context.Context, f *util.Factory, out io.Writer, c *Up
 		}
 		firstRun = !hasKubeconfig
 
+		if c.CreateKubecfgOptions.UseKubeconfig {
+			klog.Infof("hint: passing --create-kube-config=true causes the kubeconfig to be overwritten, you may not want to use this flag with --use-kubeconfig=false")
+		}
+
 		klog.Infof("Exporting kubeconfig for cluster")
 
 		conf, err := kubeconfig.BuildKubecfg(
