@@ -25,5 +25,5 @@ import (
 
 	_ "sigs.k8s.io/controller-tools/cmd/controller-gen"
 
-	_ "github.com/golangci/golangci-lint/cmd/golangci-lint"
+	_ "github.com/golangci/golangci-lint/v2/cmd/golangci-lint"
 )
