@@ -17,6 +17,7 @@ limitations under the License.
 package model
 
 import (
+	_ "embed"
 	"encoding/csv"
 	"encoding/json"
 	"fmt"
@@ -28,7 +29,6 @@ import (
 	"github.com/pelletier/go-toml"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/klog/v2"
-	"k8s.io/kops/nodeup/pkg/model/resources"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/pkg/flagbuilder"
 	"k8s.io/kops/pkg/systemd"
@@ -93,6 +93,9 @@ func (b *ContainerdBuilder) Build(c *fi.NodeupModelBuilderContext) error {
 	return nil
 }
 
+//go:embed resources/containerd-license.txt
+var ContainerdLicense string
+
 // installContainerd installs the binaries and services to run containerd.
 // We break it out because on immutable OSes we only configure containerd, we don't install it.
 func (b *ContainerdBuilder) installContainerd(c *fi.NodeupModelBuilderContext) error {
@@ -100,7 +103,7 @@ func (b *ContainerdBuilder) installContainerd(c *fi.NodeupModelBuilderContext) e
 	{
 		t := &nodetasks.File{
 			Path:     "/usr/share/doc/containerd/apache.txt",
-			Contents: fi.NewStringResource(resources.ContainerdApache2License),
+			Contents: fi.NewStringResource(ContainerdLicense),
 			Type:     nodetasks.FileType_File,
 		}
 		c.AddTask(t)
@@ -177,13 +180,19 @@ func (b *ContainerdBuilder) installContainerd(c *fi.NodeupModelBuilderContext) e
 	return nil
 }
 
-func (b *ContainerdBuilder) buildSystemdService(sv semver.Version) *nodetasks.Service {
+func (b *ContainerdBuilder) buildSystemdService(containerdVersion semver.Version) *nodetasks.Service {
 	// Based on https://github.com/containerd/containerd/blob/master/containerd.service
 
 	manifest := &systemd.Manifest{}
 	manifest.Set("Unit", "Description", "containerd container runtime")
 	manifest.Set("Unit", "Documentation", "https://containerd.io")
-	manifest.Set("Unit", "After", "network.target local-fs.target")
+	manifest.Set("Unit", "After", "network.target dbus.service")
+
+	// Restore the default SELinux security contexts for the containerd and runc binaries
+	if b.Distribution.IsRHELFamily() && b.NodeupConfig.ContainerdConfig != nil && b.NodeupConfig.ContainerdConfig.SeLinuxEnabled {
+		manifest.Set("Service", "ExecStartPre", "/bin/sh -c 'restorecon -v /usr/sbin/runc'")
+		manifest.Set("Service", "ExecStartPre", "/bin/sh -c 'restorecon -v /usr/bin/containerd*'")
+	}
 
 	manifest.Set("Service", "EnvironmentFile", "/etc/sysconfig/containerd")
 	manifest.Set("Service", "EnvironmentFile", "/etc/environment")
@@ -211,11 +220,9 @@ func (b *ContainerdBuilder) buildSystemdService(sv semver.Version) *nodetasks.Se
 
 	manifest.Set("Install", "WantedBy", "multi-user.target")
 
-	if b.NodeupConfig.KubeletConfig.CgroupDriver == "systemd" {
-		cgroup := b.NodeupConfig.KubeletConfig.RuntimeCgroups
-		if cgroup != "" {
-			manifest.Set("Service", "Slice", strings.Trim(cgroup, "/")+".slice")
-		}
+	cgroup := b.NodeupConfig.KubeletConfig.RuntimeCgroups
+	if cgroup != "" {
+		manifest.Set("Service", "Slice", strings.Trim(cgroup, "/")+".slice")
 	}
 
 	manifestString := manifest.Render()
@@ -499,8 +506,8 @@ func (b *ContainerdBuilder) buildContainerdConfig() (string, error) {
 	for name, endpoints := range containerd.RegistryMirrors {
 		config.SetPath([]string{"plugins", "io.containerd.grpc.v1.cri", "registry", "mirrors", name, "endpoint"}, endpoints)
 	}
+	config.SetPath([]string{"plugins", "io.containerd.grpc.v1.cri", "containerd", "default_runtime_name"}, "runc")
 	config.SetPath([]string{"plugins", "io.containerd.grpc.v1.cri", "containerd", "runtimes", "runc", "runtime_type"}, "io.containerd.runc.v2")
-	// only enable systemd cgroups for kubernetes >= 1.20
 	config.SetPath([]string{"plugins", "io.containerd.grpc.v1.cri", "containerd", "runtimes", "runc", "options", "SystemdCgroup"}, true)
 	if b.NodeupConfig.UsesKubenet {
 		// Using containerd with Kubenet requires special configuration.
@@ -545,7 +552,7 @@ func appendNvidiaGPURuntimeConfig(config *toml.Tree) error {
 			"privileged_without_host_devices": false,
 			"runtime_engine":                  "",
 			"runtime_root":                    "",
-			"runtime_type":                    "io.containerd.runc.v1",
+			"runtime_type":                    "io.containerd.runc.v2",
 			"options": map[string]interface{}{
 				"SystemdCgroup": true,
 				"BinaryName":    "/usr/bin/nvidia-container-runtime",
@@ -557,7 +564,6 @@ func appendNvidiaGPURuntimeConfig(config *toml.Tree) error {
 	}
 
 	config.SetPath([]string{"plugins", "io.containerd.grpc.v1.cri", "containerd", "runtimes", "nvidia"}, gpuConfig)
-	config.SetPath([]string{"plugins", "io.containerd.grpc.v1.cri", "containerd", "default_runtime_name"}, "runc")
 
 	return nil
 }
