@@ -22,12 +22,6 @@ const (
 )
 
 type TopologySpec struct {
-	// ControlPlane specifies the environment for launching the control plane nodes. (public, private)
-	ControlPlane string `json:"controlPlane,omitempty"`
-
-	// Nodes specifies the environment for launching the worker nodes. (public, private)
-	Nodes string `json:"nodes,omitempty"`
-
 	// Bastion provide an external facing point of entry into a network
 	// containing private network instances. This host can provide a single
 	// point of fortification or audit and can be started and stopped to enable
