@@ -28,6 +28,7 @@ import (
 	"k8s.io/apimachinery/pkg/util/validation/field"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/utils/ptr"
 )
 
 func Test_Validate_DNS(t *testing.T) {
@@ -189,7 +190,8 @@ func TestValidateSubnets(t *testing.T) {
 		},
 	}
 	for _, g := range grid {
-		cluster := &kops.ClusterSpec{
+		cluster := &kops.Cluster{}
+		cluster.Spec = kops.ClusterSpec{
 			CloudProvider: kops.CloudProviderSpec{
 				AWS: &kops.AWSSpec{},
 			},
@@ -198,8 +200,8 @@ func TestValidateSubnets(t *testing.T) {
 				Subnets:     g.Input,
 			},
 		}
-		_, ipNet, _ := net.ParseCIDR(cluster.Networking.NetworkCIDR)
-		errs := validateSubnets(cluster, cluster.Networking.Subnets, field.NewPath("subnets"), true, &cloudProviderConstraints{}, []*net.IPNet{ipNet}, nil, nil)
+		_, ipNet, _ := net.ParseCIDR(cluster.Spec.Networking.NetworkCIDR)
+		errs := validateSubnets(cluster, cluster.Spec.Networking.Subnets, field.NewPath("subnets"), true, &cloudProviderConstraints{}, []*net.IPNet{ipNet}, nil, nil)
 
 		testErrors(t, g.Input, errs, g.ExpectedErrors)
 	}
@@ -377,7 +379,7 @@ func TestValidateKubeControllermanager(t *testing.T) {
 		if g.Cluster == nil {
 			g.Cluster = &kops.Cluster{
 				Spec: kops.ClusterSpec{
-					KubernetesVersion: "1.28.0",
+					KubernetesVersion: "1.29.0",
 				},
 			}
 		}
@@ -434,7 +436,7 @@ func Test_Validate_Networking_Flannel(t *testing.T) {
 	for _, g := range grid {
 		cluster := &kops.Cluster{
 			Spec: kops.ClusterSpec{
-				KubernetesVersion: "1.27.0",
+				KubernetesVersion: "1.29.0",
 				Networking: kops.NetworkingSpec{
 					NetworkCIDR:           "10.0.0.0/8",
 					NonMasqueradeCIDR:     "100.64.0.0/10",
@@ -457,6 +459,72 @@ func Test_Validate_Networking_Flannel(t *testing.T) {
 	}
 }
 
+func Test_Validate_Networking_Kindnet(t *testing.T) {
+	grid := []struct {
+		Input          kops.KindnetNetworkingSpec
+		ExpectedErrors []string
+	}{
+		{
+			Input: kops.KindnetNetworkingSpec{
+				Masquerade: &kops.KindnetMasqueradeSpec{
+					Enabled: ptr.To(true),
+				},
+			},
+		},
+		{
+			Input: kops.KindnetNetworkingSpec{
+				Masquerade: &kops.KindnetMasqueradeSpec{
+					Enabled:            ptr.To(true),
+					NonMasqueradeCIDRs: []string{"10.0.0.0/24", "2001:db8::/64"},
+				},
+			},
+		},
+		{
+			Input: kops.KindnetNetworkingSpec{
+				Masquerade: &kops.KindnetMasqueradeSpec{
+					Enabled:            ptr.To(true),
+					NonMasqueradeCIDRs: []string{"a.b.c.d/24", "2001:db8::/64"},
+				},
+			},
+			ExpectedErrors: []string{"Invalid value::networking.kindnet"},
+		},
+		{
+			Input: kops.KindnetNetworkingSpec{
+				Masquerade: &kops.KindnetMasqueradeSpec{
+					Enabled:            ptr.To(false),
+					NonMasqueradeCIDRs: []string{"a.b.c.d/24", "2001:db8::/64"},
+				},
+			},
+			ExpectedErrors: []string{},
+		},
+	}
+
+	for _, g := range grid {
+		cluster := &kops.Cluster{
+			Spec: kops.ClusterSpec{
+				KubernetesVersion: "1.29.0",
+				Networking: kops.NetworkingSpec{
+					NetworkCIDR:           "10.0.0.0/8",
+					NonMasqueradeCIDR:     "100.64.0.0/10",
+					PodCIDR:               "100.96.0.0/11",
+					ServiceClusterIPRange: "100.64.0.0/13",
+					Subnets: []kops.ClusterSubnetSpec{
+						{
+							Name: "sg-test",
+							CIDR: "10.11.0.0/16",
+							Type: "Public",
+						},
+					},
+					Kindnet: &g.Input,
+				},
+			},
+		}
+
+		errs := validateNetworking(cluster, &cluster.Spec.Networking, field.NewPath("networking"), true, &cloudProviderConstraints{})
+		testErrors(t, g.Input, errs, g.ExpectedErrors)
+	}
+}
+
 func Test_Validate_Networking_OverlappingCIDR(t *testing.T) {
 	grid := []struct {
 		Name           string
@@ -528,7 +596,7 @@ func Test_Validate_Networking_OverlappingCIDR(t *testing.T) {
 		t.Run(g.Name, func(t *testing.T) {
 			cluster := &kops.Cluster{
 				Spec: kops.ClusterSpec{
-					KubernetesVersion: "1.27.0",
+					KubernetesVersion: "1.29.0",
 				},
 			}
 			cluster.Spec.Networking = g.Networking
@@ -1136,7 +1204,7 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Version: "v1.15.0",
+				Version: "v1.18.0",
 				Ingress: &kops.CiliumIngressSpec{
 					Enabled:                 fi.PtrTo(true),
 					DefaultLoadBalancerMode: "bad-value",
@@ -1146,7 +1214,7 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Version: "v1.15.0",
+				Version: "v1.18.0",
 				Ingress: &kops.CiliumIngressSpec{
 					Enabled:                 fi.PtrTo(true),
 					DefaultLoadBalancerMode: "dedicated",
@@ -1155,7 +1223,16 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Version: "v1.15.0",
+				Version: "v1.18.0",
+				GatewayAPI: &kops.CiliumGatewayAPISpec{
+					Enabled:           fi.PtrTo(true),
+					EnableSecretsSync: fi.PtrTo(true),
+				},
+			},
+		},
+		{
+			Cilium: kops.CiliumNetworkingSpec{
+				Version: "v1.18.0",
 				Hubble: &kops.HubbleSpec{
 					Enabled: fi.PtrTo(true),
 				},
@@ -1168,9 +1245,7 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 	}
 	for _, g := range grid {
-		g.Spec.Networking = kops.NetworkingSpec{
-			Cilium: &g.Cilium,
-		}
+		g.Spec.Networking.Cilium = &g.Cilium
 		if g.Spec.KubernetesVersion == "" {
 			g.Spec.KubernetesVersion = "1.17.0"
 		}
@@ -1652,7 +1727,9 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 		},
 	}
 	for _, g := range grid {
-		errs := validateNvidiaConfig(&g.Input, g.Input.Containerd.NvidiaGPU, field.NewPath("containerd", "nvidiaGPU"), true)
+		cluster := &kops.Cluster{}
+		cluster.Spec = g.Input
+		errs := validateNvidiaConfig(cluster, g.Input.Containerd.NvidiaGPU, field.NewPath("containerd", "nvidiaGPU"), true)
 		testErrors(t, g.Input, errs, g.ExpectedErrors)
 	}
 }
@@ -1701,7 +1778,9 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 		},
 	}
 	for _, g := range grid {
-		errs := validateNvidiaConfig(&g.Input, g.Input.Containerd.NvidiaGPU, field.NewPath("containerd", "nvidiaGPU"), false)
+		cluster := &kops.Cluster{}
+		cluster.Spec = g.Input
+		errs := validateNvidiaConfig(cluster, g.Input.Containerd.NvidiaGPU, field.NewPath("containerd", "nvidiaGPU"), false)
 		testErrors(t, g.Input, errs, g.ExpectedErrors)
 	}
 }
