@@ -69,6 +69,8 @@ type Config struct {
 	KubeProxy *kops.KubeProxyConfig
 	// Networking configures networking.
 	Networking kops.NetworkingSpec
+	// InstallCNIAssets specifies that the CNI network plugins need to be installed.
+	InstallCNIAssets bool `json:",omitempty"`
 	// UseCiliumEtcd is true when a Cilium etcd cluster is present.
 	UseCiliumEtcd bool `json:",omitempty"`
 	// UsesKubenet specifies that the CNI is derived from Kubenet.
@@ -116,6 +118,8 @@ type Config struct {
 	WarmPoolImages []string `json:"warmPoolImages,omitempty"`
 
 	// Azure-specific
+	// AzureAdminUser is the admin user of VMs.
+	AzureAdminUser string `json:",omitempty"`
 	// AzureLocation is the location of the resource group that the cluster is deployed in.
 	AzureLocation string `json:",omitempty"`
 	// AzureSubscriptionID is the ID of the Azure Subscription that the cluster is deployed in.
@@ -237,7 +241,7 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 	}
 
 	bootConfig := BootConfig{
-		CloudProvider:     cluster.Spec.GetCloudProvider(),
+		CloudProvider:     cluster.GetCloudProvider(),
 		ClusterName:       cluster.ObjectMeta.Name,
 		InstanceGroupName: instanceGroup.ObjectMeta.Name,
 		InstanceGroupRole: role,
@@ -278,6 +282,7 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 		config.AzureResourceGroup = cluster.AzureResourceGroupName()
 		config.AzureRouteTableName = cluster.AzureRouteTableName()
 		config.Networking.NetworkID = cluster.Spec.Networking.NetworkID
+		config.AzureAdminUser = cluster.Spec.CloudProvider.Azure.AdminUser
 	}
 
 	if cluster.Spec.CloudProvider.GCE != nil {
@@ -289,14 +294,19 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 
 	config.Openstack = cluster.Spec.CloudProvider.Openstack
 
-	if instanceGroup.Spec.UpdatePolicy != nil {
+	switch {
+	case instanceGroup.Spec.UpdatePolicy != nil:
 		config.UpdatePolicy = *instanceGroup.Spec.UpdatePolicy
-	} else if cluster.Spec.UpdatePolicy != nil {
+	case cluster.Spec.UpdatePolicy != nil:
 		config.UpdatePolicy = *cluster.Spec.UpdatePolicy
-	} else {
+	default:
 		config.UpdatePolicy = kops.UpdatePolicyAutomatic
 	}
 
+	if cluster.InstallCNIAssets() {
+		config.InstallCNIAssets = true
+	}
+
 	if cluster.Spec.Networking.AmazonVPC != nil {
 		config.Networking.AmazonVPC = &kops.AmazonVPCNetworkingSpec{}
 		config.DefaultMachineType = aws.String(strings.Split(instanceGroup.Spec.MachineType, ",")[0])
@@ -328,6 +338,10 @@ func NewConfig(cluster *kops.Cluster, instanceGroup *kops.InstanceGroup) (*Confi
 		config.Networking.KubeRouter = &kops.KuberouterNetworkingSpec{}
 	}
 
+	if cluster.Spec.Networking.Kindnet != nil {
+		config.Networking.Kindnet = &kops.KindnetNetworkingSpec{}
+	}
+
 	if instanceGroup.Spec.Kubelet != nil {
 		config.KubeletConfig = *instanceGroup.Spec.Kubelet
 	}
