@@ -28,7 +28,6 @@ import (
 	"net"
 	"os"
 	"path"
-	"path/filepath"
 	"sort"
 	"strconv"
 	"strings"
@@ -68,6 +67,12 @@ type ToolboxEnrollOptions struct {
 	SSHUser string
 	SSHPort int
 
+	// BuildHost is a flag to only build the host resource, don't apply it or enroll the node
+	BuildHost bool
+
+	// PodCIDRs is the list of IP Address ranges to use for pods that run on this node
+	PodCIDRs []string
+
 	kubeconfig.CreateKubecfgOptions
 }
 
@@ -86,6 +91,11 @@ func RunToolboxEnroll(ctx context.Context, f commandutils.Factory, out io.Writer
 	if options.InstanceGroup == "" {
 		return fmt.Errorf("instance-group is required")
 	}
+	if options.Host == "" {
+		// Technically we could build the host resource without the PKI, but this isn't the case we are targeting right now.
+		return fmt.Errorf("host is required")
+	}
+
 	clientset, err := f.KopsClient()
 	if err != nil {
 		return err
@@ -101,6 +111,36 @@ func RunToolboxEnroll(ctx context.Context, f commandutils.Factory, out io.Writer
 	if err != nil {
 		return err
 	}
+
+	// Enroll the node over SSH.
+	restConfig, err := f.RESTConfig(ctx, fullCluster, options.CreateKubecfgOptions)
+	if err != nil {
+		return err
+	}
+
+	sudo := options.SSHUser != "root"
+
+	sshTarget, err := NewSSHHost(ctx, options.Host, options.SSHPort, options.SSHUser, sudo)
+	if err != nil {
+		return err
+	}
+	defer sshTarget.Close()
+
+	hostData, err := buildHostData(ctx, sshTarget, options)
+	if err != nil {
+		return err
+	}
+
+	if options.BuildHost {
+		klog.Infof("building host data for %+v", hostData)
+		b, err := yaml.Marshal(hostData)
+		if err != nil {
+			return fmt.Errorf("error marshalling host data: %w", err)
+		}
+		fmt.Fprintf(out, "%s\n", string(b))
+		return nil
+	}
+
 	fullInstanceGroup, err := configBuilder.GetFullInstanceGroup(ctx)
 	if err != nil {
 		return err
@@ -110,22 +150,58 @@ func RunToolboxEnroll(ctx context.Context, f commandutils.Factory, out io.Writer
 		return err
 	}
 
-	// Enroll the node over SSH.
-	if options.Host != "" {
-		restConfig, err := f.RESTConfig(ctx, fullCluster, options.CreateKubecfgOptions)
-		if err != nil {
-			return err
-		}
-
-		if err := enrollHost(ctx, fullInstanceGroup, options, bootstrapData, restConfig); err != nil {
-			return err
-		}
+	if err := enrollHost(ctx, fullInstanceGroup, bootstrapData, restConfig, hostData, sshTarget); err != nil {
+		return err
 	}
 
 	return nil
 }
 
-func enrollHost(ctx context.Context, ig *kops.InstanceGroup, options *ToolboxEnrollOptions, bootstrapData *BootstrapData, restConfig *rest.Config) error {
+// buildHostData builds an instance of the Host CRD, based on information in the options and by SSHing to the target host.
+func buildHostData(ctx context.Context, sshTarget *SSHHost, options *ToolboxEnrollOptions) (*v1alpha2.Host, error) {
+	publicKeyPath := "/etc/kubernetes/kops/pki/machine/public.pem"
+
+	publicKeyBytes, err := sshTarget.readFile(ctx, publicKeyPath)
+	if err != nil {
+		if errors.Is(err, fs.ErrNotExist) {
+			publicKeyBytes = nil
+		} else {
+			return nil, fmt.Errorf("error reading public key %q: %w", publicKeyPath, err)
+		}
+	}
+
+	// Create the key if it doesn't exist
+	publicKeyBytes = bytes.TrimSpace(publicKeyBytes)
+	if len(publicKeyBytes) == 0 {
+		if _, err := sshTarget.runScript(ctx, scriptCreateKey, ExecOptions{Echo: true}); err != nil {
+			return nil, err
+		}
+
+		b, err := sshTarget.readFile(ctx, publicKeyPath)
+		if err != nil {
+			return nil, fmt.Errorf("error reading public key %q (after creation): %w", publicKeyPath, err)
+		}
+		publicKeyBytes = b
+	}
+	klog.Infof("public key is %s", string(publicKeyBytes))
+
+	hostname, err := sshTarget.getHostname(ctx)
+	if err != nil {
+		return nil, err
+	}
+
+	host := &v1alpha2.Host{}
+	host.SetGroupVersionKind(v1alpha2.SchemeGroupVersion.WithKind("Host"))
+	host.Namespace = "kops-system"
+	host.Name = hostname
+	host.Spec.InstanceGroup = options.InstanceGroup
+	host.Spec.PublicKey = string(publicKeyBytes)
+	host.Spec.PodCIDRs = options.PodCIDRs
+
+	return host, nil
+}
+
+func enrollHost(ctx context.Context, ig *kops.InstanceGroup, bootstrapData *BootstrapData, restConfig *rest.Config, hostData *v1alpha2.Host, sshTarget *SSHHost) error {
 	scheme := runtime.NewScheme()
 	if err := v1alpha2.AddToScheme(scheme); err != nil {
 		return fmt.Errorf("building kubernetes scheme: %w", err)
@@ -137,83 +213,28 @@ func enrollHost(ctx context.Context, ig *kops.InstanceGroup, options *ToolboxEnr
 		return fmt.Errorf("building kubernetes client: %w", err)
 	}
 
-	sudo := true
-	if options.SSHUser == "root" {
-		sudo = false
-	}
-
-	host, err := NewSSHHost(ctx, options.Host, options.SSHPort, options.SSHUser, sudo)
-	if err != nil {
-		return err
-	}
-	defer host.Close()
-
-	publicKeyPath := "/etc/kubernetes/kops/pki/machine/public.pem"
-
-	publicKeyBytes, err := host.readFile(ctx, publicKeyPath)
-	if err != nil {
-		if errors.Is(err, fs.ErrNotExist) {
-			publicKeyBytes = nil
-		} else {
-			return fmt.Errorf("error reading public key %q: %w", publicKeyPath, err)
-		}
-	}
-
-	publicKeyBytes = bytes.TrimSpace(publicKeyBytes)
-	if len(publicKeyBytes) == 0 {
-		if _, err := host.runScript(ctx, scriptCreateKey, ExecOptions{Sudo: sudo, Echo: true}); err != nil {
-			return err
-		}
-
-		b, err := host.readFile(ctx, publicKeyPath)
-		if err != nil {
-			return fmt.Errorf("error reading public key %q (after creation): %w", publicKeyPath, err)
-		}
-		publicKeyBytes = b
-	}
-	klog.Infof("public key is %s", string(publicKeyBytes))
-
-	hostname, err := host.getHostname(ctx)
-	if err != nil {
-		return err
-	}
-
 	// We can't create the host resource in the API server for control-plane nodes,
 	// because the API server (likely) isn't running yet.
 	if !ig.IsControlPlane() {
-		if err := createHostResourceInAPIServer(ctx, options, hostname, publicKeyBytes, kubeClient); err != nil {
-			return err
+		if err := kubeClient.Create(ctx, hostData); err != nil {
+			return fmt.Errorf("failed to create host %s/%s: %w", hostData.Namespace, hostData.Name, err)
 		}
 	}
 
 	for k, v := range bootstrapData.NodeupScriptAdditionalFiles {
-		if err := host.writeFile(ctx, k, bytes.NewReader(v)); err != nil {
+		if err := sshTarget.writeFile(ctx, k, bytes.NewReader(v)); err != nil {
 			return fmt.Errorf("writing file %q over SSH: %w", k, err)
 		}
 	}
 
 	if len(bootstrapData.NodeupScript) != 0 {
-		if _, err := host.runScript(ctx, string(bootstrapData.NodeupScript), ExecOptions{Sudo: sudo, Echo: true}); err != nil {
+		if _, err := sshTarget.runScript(ctx, string(bootstrapData.NodeupScript), ExecOptions{Echo: true}); err != nil {
 			return err
 		}
 	}
 	return nil
 }
 
-func createHostResourceInAPIServer(ctx context.Context, options *ToolboxEnrollOptions, nodeName string, publicKey []byte, client client.Client) error {
-	host := &v1alpha2.Host{}
-	host.Namespace = "kops-system"
-	host.Name = nodeName
-	host.Spec.InstanceGroup = options.InstanceGroup
-	host.Spec.PublicKey = string(publicKey)
-
-	if err := client.Create(ctx, host); err != nil {
-		return fmt.Errorf("failed to create host %s/%s: %w", host.Namespace, host.Name, err)
-	}
-
-	return nil
-}
-
 const scriptCreateKey = `
 #!/bin/bash
 set -o errexit
@@ -265,6 +286,16 @@ func NewSSHHost(ctx context.Context, host string, sshPort int, sshUser string, s
 
 	agentClient := agent.NewClient(conn)
 
+	signers, err := agentClient.Signers()
+	if err != nil {
+		_ = conn.Close()
+		return nil, fmt.Errorf("failed to get signers: %w", err)
+	}
+
+	if len(signers) == 0 {
+		return nil, fmt.Errorf("SSH agent has no keys")
+	}
+
 	sshConfig := &ssh.ClientConfig{
 		HostKeyCallback: func(hostname string, remote net.Addr, key ssh.PublicKey) error {
 			klog.Warningf("accepting SSH key %v for %q", key, hostname)
@@ -314,7 +345,7 @@ func (s *SSHHost) runScript(ctx context.Context, script string, options ExecOpti
 	p := vfs.NewSSHPath(s.sshClient, s.hostname, scriptPath, s.sudo)
 
 	defer func() {
-		if _, err := s.runCommand(ctx, "rm -rf "+tempDir, ExecOptions{Sudo: s.sudo, Echo: false}); err != nil {
+		if _, err := s.runCommand(ctx, "rm -rf "+tempDir, ExecOptions{Echo: false}); err != nil {
 			klog.Warningf("error cleaning up temp directory %q: %v", tempDir, err)
 		}
 	}()
@@ -335,7 +366,6 @@ type CommandOutput struct {
 
 // ExecOptions holds options for running a command remotely.
 type ExecOptions struct {
-	Sudo bool
 	Echo bool
 }
 
@@ -352,10 +382,11 @@ func (s *SSHHost) runCommand(ctx context.Context, command string, options ExecOp
 	session.Stderr = &output.Stderr
 
 	if options.Echo {
-		session.Stdout = io.MultiWriter(os.Stdout, session.Stdout)
+		// We send both to stderr, so we don't "corrupt" stdout
+		session.Stdout = io.MultiWriter(os.Stderr, session.Stdout)
 		session.Stderr = io.MultiWriter(os.Stderr, session.Stderr)
 	}
-	if options.Sudo {
+	if s.sudo {
 		command = "sudo " + command
 	}
 	if err := session.Run(command); err != nil {
@@ -367,7 +398,7 @@ func (s *SSHHost) runCommand(ctx context.Context, command string, options ExecOp
 // getHostname gets the hostname of the SSH target.
 // This is used as the node name when registering the node.
 func (s *SSHHost) getHostname(ctx context.Context) (string, error) {
-	output, err := s.runCommand(ctx, "hostname", ExecOptions{Sudo: false, Echo: true})
+	output, err := s.runCommand(ctx, "hostname", ExecOptions{Echo: true})
 	if err != nil {
 		return "", fmt.Errorf("failed to get hostname: %w", err)
 	}
@@ -803,7 +834,113 @@ func (b *ConfigBuilder) GetBootstrapData(ctx context.Context) (*BootstrapData, e
 		return nil, err
 	}
 
+	vfsContext := clientset.VFSContext()
+
+	// If this is the control plane, we want to copy the config from s3/gcs to the local file system on the target node,
+	// so that we don't need credentials to the state store.
 	if bootConfig.InstanceGroupRole == kops.InstanceGroupRoleControlPlane {
+		remapPrefix := "s3://" // TODO: Support GCS?
+
+		// targetDir is the location of the config on the target node.
+		targetDir := "/etc/kubernetes/kops/config"
+
+		// remapFile remaps a file from s3/gcs etc to the local file system on the target node.
+		remapFile := func(pSrc *string, destDir string) error {
+			src := *pSrc
+			if !strings.HasPrefix(src, remapPrefix) {
+				return nil
+			}
+
+			srcPath, err := vfsContext.BuildVfsPath(src)
+			if err != nil {
+				return fmt.Errorf("building vfs path: %w", err)
+			}
+			b, err := srcPath.ReadFile(ctx)
+			if err != nil {
+				return fmt.Errorf("reading file: %w", err)
+			}
+
+			dest := strings.TrimPrefix(src, remapPrefix)
+			dest = path.Join(destDir, dest)
+			bootstrapData.NodeupScriptAdditionalFiles[dest] = b
+
+			*pSrc = dest
+			return nil
+		}
+
+		// remapTree remaps a file tree from s3/gcs etc to the local file system on the target node.
+		remapTree := func(pSrc *string, dest string) error {
+			src := *pSrc
+			if !strings.HasPrefix(src, remapPrefix) {
+				return nil
+			}
+
+			srcPath, err := vfsContext.BuildVfsPath(src)
+			if err != nil {
+				return fmt.Errorf("building vfs path: %w", err)
+			}
+
+			srcFiles, err := srcPath.ReadTree(ctx)
+			if err != nil {
+				return fmt.Errorf("reading tree: %w", err)
+			}
+			basePath := srcPath.Path()
+			for _, srcFile := range srcFiles {
+				b, err := srcFile.ReadFile(ctx)
+				if err != nil {
+					return fmt.Errorf("reading file: %w", err)
+				}
+
+				if !strings.HasPrefix(srcFile.Path(), basePath) {
+					return fmt.Errorf("unexpected path: %q", srcFile.Path())
+				}
+				relativePath := strings.TrimPrefix(srcFile.Path(), basePath)
+
+				bootstrapData.NodeupScriptAdditionalFiles[path.Join(dest, relativePath)] = b
+			}
+
+			*pSrc = dest
+			return nil
+		}
+
+		for i := range nodeupConfig.EtcdManifests {
+			if err := remapFile(&nodeupConfig.EtcdManifests[i], path.Join(targetDir)); err != nil {
+				return nil, err
+			}
+		}
+
+		configBase, err := vfs.Context.BuildVfsPath(cluster.Spec.ConfigStore.Base)
+		if err != nil {
+			return nil, fmt.Errorf("parsing configStore.base %q: %w", cluster.Spec.ConfigStore.Base, err)
+		}
+		for i, channel := range nodeupConfig.Channels {
+			bootstrapChannelPath := configBase.Join("addons", "bootstrap-channel.yaml").Path()
+			if channel != bootstrapChannelPath {
+				klog.Infof("not remapping non-bootstrap channel %q", channel)
+				continue
+			}
+
+			parentPath := configBase.Join("addons").Path()
+			if err := remapTree(&parentPath, path.Join(targetDir, "addons")); err != nil {
+				return nil, err
+			}
+			nodeupConfig.Channels[i] = path.Join(parentPath, "bootstrap-channel.yaml")
+
+			// The channels tool requires a file:// prefix
+			if strings.HasPrefix(nodeupConfig.Channels[i], "/") {
+				nodeupConfig.Channels[i] = "file://" + nodeupConfig.Channels[i]
+			}
+		}
+
+		if nodeupConfig.ConfigStore != nil {
+			if err := remapTree(&nodeupConfig.ConfigStore.Keypairs, path.Join(targetDir, "pki/etcd")); err != nil {
+				return nil, err
+			}
+			if err := remapTree(&nodeupConfig.ConfigStore.Secrets, path.Join(targetDir, "pki")); err != nil {
+				return nil, err
+			}
+		}
+
 		nodeupConfigBytes, err := yaml.Marshal(nodeupConfig)
 		if err != nil {
 			return nil, fmt.Errorf("error converting nodeup config to yaml: %w", err)
@@ -812,7 +949,7 @@ func (b *ConfigBuilder) GetBootstrapData(ctx context.Context) (*BootstrapData, e
 		// sum256 := sha256.Sum256(nodeupConfigBytes)
 		// bootConfig.NodeupConfigHash = base64.StdEncoding.EncodeToString(sum256[:])
 
-		p := filepath.Join("/etc/kubernetes/kops/config", "igconfig", bootConfig.InstanceGroupRole.ToLowerString(), ig.Name, "nodeupconfig.yaml")
+		p := path.Join(targetDir, "igconfig", bootConfig.InstanceGroupRole.ToLowerString(), ig.Name, "nodeupconfig.yaml")
 		bootstrapData.NodeupScriptAdditionalFiles[p] = nodeupConfigBytes
 
 		// Copy any static manifests we need on the control plane
@@ -820,7 +957,7 @@ func (b *ConfigBuilder) GetBootstrapData(ctx context.Context) (*BootstrapData, e
 			if !staticManifest.AppliesToRole(bootConfig.InstanceGroupRole) {
 				continue
 			}
-			p := filepath.Join("/etc/kubernetes/kops/config", staticManifest.Path)
+			p := path.Join(targetDir, staticManifest.Path)
 			bootstrapData.NodeupScriptAdditionalFiles[p] = staticManifest.Contents
 		}
 	}
