@@ -102,16 +102,19 @@ func (b *Client) Query(ctx context.Context, req any, resp any) error {
 	if err != nil {
 		return err
 	}
-	if response.Body != nil {
-		defer response.Body.Close()
-	}
-
 	// if we receive StatusConflict it means that we should exit gracefully
 	if response.StatusCode == http.StatusConflict {
 		klog.Infof("kops-controller returned status code %d", response.StatusCode)
+		if response.Body != nil {
+			response.Body.Close()
+		}
 		os.Exit(0)
 	}
 
+	if response.Body != nil {
+		defer response.Body.Close()
+	}
+
 	if response.StatusCode != http.StatusOK {
 		detail := ""
 		if response.Body != nil {
@@ -125,3 +128,9 @@ func (b *Client) Query(ctx context.Context, req any, resp any) error {
 
 	return json.NewDecoder(response.Body).Decode(resp)
 }
+
+func (b *Client) Close() {
+	if b.httpClient != nil {
+		b.httpClient.CloseIdleConnections()
+	}
+}
