@@ -27,11 +27,13 @@ import (
 	"k8s.io/kops/pkg/apis/nodeup"
 	"k8s.io/kops/pkg/assets"
 	"k8s.io/kops/pkg/model/resources"
+	"k8s.io/kops/pkg/nodemodel/wellknownassets"
 	"k8s.io/kops/pkg/wellknownservices"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/fitasks"
 	"k8s.io/kops/upup/pkg/fi/utils"
 	"k8s.io/kops/util/pkg/architectures"
+	"k8s.io/kops/util/pkg/vfs"
 )
 
 type NodeUpConfigBuilder interface {
@@ -65,6 +67,8 @@ type BootstrapScript struct {
 
 	// nodeupConfig contains the nodeup config.
 	nodeupConfig fi.CloudupTaskDependentResource
+	// nodeupScript contains the nodeup bootstrap script, for use with Karpenter.
+	nodeupScript fi.CloudupTaskDependentResource
 }
 
 var (
@@ -74,7 +78,7 @@ var (
 )
 
 // kubeEnv returns the boot config for the instance group
-func (b *BootstrapScript) kubeEnv(ig *kops.InstanceGroup, c *fi.CloudupContext) (*nodeup.BootConfig, error) {
+func (b *BootstrapScript) kubeEnv(cluster *kops.Cluster, ig *kops.InstanceGroup, c *fi.CloudupContext) (*nodeup.BootConfig, error) {
 	wellKnownAddresses := make(WellKnownAddresses)
 
 	for _, hasAddress := range b.hasAddressTasks {
@@ -121,6 +125,40 @@ func (b *BootstrapScript) kubeEnv(ig *kops.InstanceGroup, c *fi.CloudupContext)
 	bootConfig.NodeupConfigHash = base64.StdEncoding.EncodeToString(sum256[:])
 	b.nodeupConfig.Resource = fi.NewBytesResource(configData)
 
+	if ig.Spec.Manager == kops.InstanceManagerKarpenter {
+		assetBuilder := assets.NewAssetBuilder(vfs.NewVFSContext(), cluster.Spec.Assets, false)
+		nodeUpAssets := make(map[architectures.Architecture]*assets.MirroredAsset)
+		for _, arch := range architectures.GetSupported() {
+			asset, err := wellknownassets.NodeUpAsset(assetBuilder, arch)
+			if err != nil {
+				return nil, err
+			}
+			nodeUpAssets[arch] = asset
+		}
+
+		var nodeupScript resources.NodeUpScript
+		nodeupScript.NodeUpAssets = nodeUpAssets
+		nodeupScript.BootConfig = bootConfig
+
+		nodeupScript.WithEnvironmentVariables(cluster, ig)
+		nodeupScript.WithProxyEnv(cluster)
+		nodeupScript.WithSysctls()
+
+		nodeupScript.CompressUserData = fi.ValueOf(ig.Spec.CompressUserData)
+
+		nodeupScript.CloudProvider = string(cluster.GetCloudProvider())
+
+		scriptResource, err := nodeupScript.Build()
+		if err != nil {
+			return nil, err
+		}
+		scriptData, err := fi.ResourceAsBytes(scriptResource)
+		if err != nil {
+			return nil, err
+		}
+		b.nodeupScript.Resource = fi.NewBytesResource(scriptData)
+	}
+
 	return bootConfig, nil
 }
 
@@ -194,6 +232,7 @@ func (b *BootstrapScriptBuilder) ResourceNodeUp(c *fi.CloudupModelBuilderContext
 	}
 	task.resource.Task = task
 	task.nodeupConfig.Task = task
+	task.nodeupScript.Task = task
 	c.AddTask(task)
 
 	c.AddTask(&fitasks.ManagedFile{
@@ -202,6 +241,14 @@ func (b *BootstrapScriptBuilder) ResourceNodeUp(c *fi.CloudupModelBuilderContext
 		Location:  fi.PtrTo("igconfig/" + ig.Spec.Role.ToLowerString() + "/" + ig.Name + "/nodeupconfig.yaml"),
 		Contents:  &task.nodeupConfig,
 	})
+	if ig.Spec.Manager == kops.InstanceManagerKarpenter {
+		c.AddTask(&fitasks.ManagedFile{
+			Name:      fi.PtrTo("nodeupscript-" + ig.Name),
+			Lifecycle: b.Lifecycle,
+			Location:  fi.PtrTo("igconfig/" + ig.Spec.Role.ToLowerString() + "/" + ig.Name + "/nodeupscript.sh"),
+			Contents:  &task.nodeupScript,
+		})
+	}
 	return &task.resource, nil
 }
 
@@ -231,7 +278,7 @@ func (b *BootstrapScript) Run(c *fi.CloudupContext) error {
 		return nil
 	}
 
-	bootConfig, err := b.kubeEnv(b.ig, c)
+	bootConfig, err := b.kubeEnv(b.cluster, b.ig, c)
 	if err != nil {
 		return err
 	}
