@@ -97,29 +97,35 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(cluster *kops.Cluster) error
 	}
 	c.Image = image
 
-	switch cluster.GetCloudProvider() {
-	case kops.CloudProviderAWS:
-		c.CloudProvider = "aws"
-	case kops.CloudProviderGCE:
-		c.CloudProvider = "gce"
-	case kops.CloudProviderDO:
-		c.CloudProvider = "external"
-	case kops.CloudProviderHetzner:
-		c.CloudProvider = "external"
-	case kops.CloudProviderOpenstack:
-		c.CloudProvider = "openstack"
-	case kops.CloudProviderAzure:
-		c.CloudProvider = "azure"
-	case kops.CloudProviderScaleway:
-		c.CloudProvider = "external"
-	case kops.CloudProviderMetal:
-		c.CloudProvider = "external"
-	default:
-		return fmt.Errorf("unknown cloudprovider %q", cluster.GetCloudProvider())
-	}
+	if b.controlPlaneKubernetesVersion.IsLT("1.33") {
+		if b.controlPlaneKubernetesVersion.IsLT("1.31") {
+			switch cluster.GetCloudProvider() {
+			case kops.CloudProviderAWS:
+				c.CloudProvider = "aws"
+			case kops.CloudProviderGCE:
+				c.CloudProvider = "gce"
+			case kops.CloudProviderDO:
+				c.CloudProvider = "external"
+			case kops.CloudProviderHetzner:
+				c.CloudProvider = "external"
+			case kops.CloudProviderOpenstack:
+				c.CloudProvider = "openstack"
+			case kops.CloudProviderAzure:
+				c.CloudProvider = "azure"
+			case kops.CloudProviderScaleway:
+				c.CloudProvider = "external"
+			case kops.CloudProviderMetal:
+				c.CloudProvider = "external"
+			default:
+				return fmt.Errorf("unknown cloudprovider %q", cluster.GetCloudProvider())
+			}
 
-	if clusterSpec.ExternalCloudControllerManager != nil {
-		c.CloudProvider = "external"
+			if clusterSpec.ExternalCloudControllerManager != nil {
+				c.CloudProvider = "external"
+			}
+		} else {
+			c.CloudProvider = "external"
+		}
 	}
 
 	c.LogLevel = 2
@@ -145,21 +151,21 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(cluster *kops.Cluster) error
 		}
 	}
 
-	// TODO: We can probably rewrite these more clearly in descending order
 	// Based on recommendations from:
-	// https://kubernetes.io/docs/admin/admission-controllers/#is-there-a-recommended-set-of-admission-controllers-to-use
+	// https://kubernetes.io/docs/reference/access-authn-authz/admission-controllers/
 	{
 		c.EnableAdmissionPlugins = []string{
-			"NamespaceLifecycle",
-			"LimitRanger",
-			"ServiceAccount",
-			//"PersistentVolumeLabel",
 			"DefaultStorageClass",
 			"DefaultTolerationSeconds",
+			"LimitRanger",
 			"MutatingAdmissionWebhook",
-			"ValidatingAdmissionWebhook",
+			"NamespaceLifecycle",
 			"NodeRestriction",
 			"ResourceQuota",
+			"RuntimeClass",
+			"ServiceAccount",
+			"ValidatingAdmissionPolicy",
+			"ValidatingAdmissionWebhook",
 		}
 		c.EnableAdmissionPlugins = append(c.EnableAdmissionPlugins, c.AppendAdmissionPlugins...)
 	}
@@ -188,10 +194,6 @@ func (b *KubeAPIServerOptionsBuilder) BuildOptions(cluster *kops.Cluster) error
 		if _, found := c.FeatureGates["InTreePluginAWSUnregister"]; !found && b.ControlPlaneKubernetesVersion().IsLT("1.31") {
 			c.FeatureGates["InTreePluginAWSUnregister"] = "true"
 		}
-
-		if _, found := c.FeatureGates["CSIMigrationAWS"]; !found && b.ControlPlaneKubernetesVersion().IsLT("1.27") {
-			c.FeatureGates["CSIMigrationAWS"] = "true"
-		}
 	}
 
 	return nil
