@@ -42,23 +42,29 @@ func (b *ContainerdOptionsBuilder) BuildOptions(o *kops.Cluster) error {
 	// Set version based on Kubernetes version
 	if fi.ValueOf(containerd.Version) == "" {
 		switch {
-		case b.IsKubernetesLT("1.27.2"):
-			containerd.Version = fi.PtrTo("1.6.20")
+		case b.IsKubernetesLT("1.32"):
+			containerd.Version = fi.PtrTo("1.7.29")
 			containerd.Runc = &kops.Runc{
-				Version: fi.PtrTo("1.1.5"),
+				Version: fi.PtrTo("1.3.3"),
 			}
 		default:
-			containerd.Version = fi.PtrTo("1.7.28")
+			containerd.Version = fi.PtrTo("2.1.5")
 			containerd.Runc = &kops.Runc{
-				Version: fi.PtrTo("1.3.0"),
+				Version: fi.PtrTo("1.3.3"),
 			}
 		}
 	}
 	// Set default log level to INFO
 	containerd.LogLevel = fi.PtrTo("info")
 
-	if containerd.NvidiaGPU != nil && fi.ValueOf(containerd.NvidiaGPU.Enabled) && containerd.NvidiaGPU.DriverPackage == "" {
-		containerd.NvidiaGPU.DriverPackage = kops.NvidiaDefaultDriverPackage
+	if containerd.NvidiaGPU != nil && fi.ValueOf(containerd.NvidiaGPU.Enabled) {
+		if containerd.NvidiaGPU.DriverPackage == "" {
+			containerd.NvidiaGPU.DriverPackage = kops.NvidiaDefaultDriverPackage
+		}
+
+		if containerd.NvidiaGPU.DevicePluginImage == "" {
+			containerd.NvidiaGPU.DevicePluginImage = kops.NvidiaDevicePluginImage
+		}
 	}
 
 	return nil
