@@ -24,6 +24,7 @@ import (
 	"strings"
 
 	"k8s.io/kops/pkg/apis/kops"
+	kopsmodel "k8s.io/kops/pkg/apis/kops/model"
 	"k8s.io/kops/pkg/apis/kops/util"
 	"k8s.io/kops/pkg/assets"
 	"k8s.io/kops/pkg/k8sversion"
@@ -38,15 +39,59 @@ import (
 type OptionsContext struct {
 	ClusterName string
 
+	// Deprecated: Prefer using NodeKubernetesVersion() and ControlPlaneKubernetesVersion()
 	KubernetesVersion semver.Version
 
 	AssetBuilder *assets.AssetBuilder
+
+	nodeKubernetesVersion         kopsmodel.KubernetesVersion
+	controlPlaneKubernetesVersion kopsmodel.KubernetesVersion
 }
 
+func NewOptionsContext(cluster *kops.Cluster, assetBuilder *assets.AssetBuilder, maxKubeletSupportedVersion string) (*OptionsContext, error) {
+	optionsContext := &OptionsContext{
+		ClusterName:  cluster.ObjectMeta.Name,
+		AssetBuilder: assetBuilder,
+	}
+
+	sv, err := util.ParseKubernetesVersion(cluster.Spec.KubernetesVersion)
+	if err != nil {
+		return nil, fmt.Errorf("unable to determine kubernetes version from %q", cluster.Spec.KubernetesVersion)
+	}
+	optionsContext.KubernetesVersion = *sv
+
+	controlPlaneKubernetesVersion, err := kopsmodel.ParseKubernetesVersion(cluster.Spec.KubernetesVersion)
+	if err != nil {
+		return nil, fmt.Errorf("unable to determine kubernetes version from %q: %w", cluster.Spec.KubernetesVersion, err)
+	}
+	nodeKubernetesVersion := controlPlaneKubernetesVersion
+	if maxKubeletSupportedVersion != "" {
+		nodeKubernetesVersion, err = kopsmodel.ParseKubernetesVersion(maxKubeletSupportedVersion)
+		if err != nil {
+			return nil, fmt.Errorf("unable to determine kubernetes version from %q: %w", maxKubeletSupportedVersion, err)
+		}
+	}
+
+	optionsContext.nodeKubernetesVersion = *nodeKubernetesVersion
+	optionsContext.controlPlaneKubernetesVersion = *controlPlaneKubernetesVersion
+
+	return optionsContext, nil
+}
+
+func (c *OptionsContext) NodeKubernetesVersion() kopsmodel.KubernetesVersion {
+	return c.nodeKubernetesVersion
+}
+
+func (c *OptionsContext) ControlPlaneKubernetesVersion() kopsmodel.KubernetesVersion {
+	return c.controlPlaneKubernetesVersion
+}
+
+// Deprecated: prefer using NodeKubernetesVersion() and ControlPlaneKubernetesVersion()
 func (c *OptionsContext) IsKubernetesGTE(version string) bool {
 	return util.IsKubernetesGTE(version, c.KubernetesVersion)
 }
 
+// Deprecated: prefer using NodeKubernetesVersion() and ControlPlaneKubernetesVersion()
 func (c *OptionsContext) IsKubernetesLT(version string) bool {
 	return !c.IsKubernetesGTE(version)
 }
@@ -89,10 +134,6 @@ func WellKnownServiceIP(networkingSpec *kops.NetworkingSpec, id int) (net.IP, er
 	return nil, fmt.Errorf("unexpected IP address type for ServiceClusterIPRange: %s", networkingSpec.ServiceClusterIPRange)
 }
 
-func IsBaseURL(kubernetesVersion string) bool {
-	return strings.HasPrefix(kubernetesVersion, "http:") || strings.HasPrefix(kubernetesVersion, "https:") || strings.HasPrefix(kubernetesVersion, "memfs:")
-}
-
 // Image returns the docker image name for the specified component
 func Image(component string, clusterSpec *kops.ClusterSpec, assetsBuilder *assets.AssetBuilder) (string, error) {
 	if assetsBuilder == nil {
@@ -106,14 +147,10 @@ func Image(component string, clusterSpec *kops.ClusterSpec, assetsBuilder *asset
 
 	imageName := component
 
-	if !IsBaseURL(clusterSpec.KubernetesVersion) {
+	if !kopsmodel.IsBaseURL(clusterSpec.KubernetesVersion) {
 		image := "registry.k8s.io/" + imageName + ":" + "v" + kubernetesVersion.String()
 
-		image, err := assetsBuilder.RemapImage(image)
-		if err != nil {
-			return "", fmt.Errorf("unable to remap container %q: %v", image, err)
-		}
-		return image, nil
+		return assetsBuilder.RemapImage(image), nil
 	}
 
 	// The simple name is valid when pulling.  But if we
