@@ -171,7 +171,7 @@ metadata:
 spec:
   containers:
   - name: etcd-manager
-    image: registry.k8s.io/etcd-manager/etcd-manager-slim:v3.0.20241012
+    image: registry.k8s.io/etcd-manager/etcd-manager-slim:v3.0.20250917
     resources:
       requests:
         cpu: 100m
@@ -208,7 +208,7 @@ spec:
     emptyDir: {}
 `
 
-const kopsUtilsImage = "registry.k8s.io/kops/kops-utils-cp:1.32.1"
+const kopsUtilsImage = "registry.k8s.io/kops/kops-utils-cp:1.34.1"
 
 // buildPod creates the pod spec, based on the EtcdClusterSpec
 func (b *EtcdManagerBuilder) buildPod(etcdCluster kops.EtcdClusterSpec, instanceGroupName string) (*v1.Pod, error) {
@@ -236,7 +236,22 @@ func (b *EtcdManagerBuilder) buildPod(etcdCluster kops.EtcdClusterSpec, instance
 		}
 	}
 
-	{
+	if b.Cluster.HasImageVolumesSupport() {
+		for _, etcdVersion := range etcdSupportedVersions() {
+			if etcdVersion.SymlinkToVersion == "" {
+				volume := v1.Volume{
+					Name: "etcd-v" + strings.ReplaceAll(etcdVersion.Version, ".", "-"),
+					VolumeSource: v1.VolumeSource{
+						Image: &v1.ImageVolumeSource{
+							Reference:  b.AssetBuilder.RemapImage(etcdVersion.Image),
+							PullPolicy: v1.PullIfNotPresent,
+						},
+					},
+				}
+				pod.Spec.Volumes = append(pod.Spec.Volumes, volume)
+			}
+		}
+	} else {
 		utilMounts := []v1.VolumeMount{
 			{
 				MountPath: "/opt",
@@ -314,11 +329,7 @@ func (b *EtcdManagerBuilder) buildPod(etcdCluster kops.EtcdClusterSpec, instance
 		// Remap image via AssetBuilder
 		for i := range pod.Spec.InitContainers {
 			initContainer := &pod.Spec.InitContainers[i]
-			remapped, err := b.AssetBuilder.RemapImage(initContainer.Image)
-			if err != nil {
-				return nil, fmt.Errorf("unable to remap init container image %q: %w", container.Image, err)
-			}
-			initContainer.Image = remapped
+			initContainer.Image = b.AssetBuilder.RemapImage(initContainer.Image)
 		}
 	}
 
@@ -334,11 +345,21 @@ func (b *EtcdManagerBuilder) buildPod(etcdCluster kops.EtcdClusterSpec, instance
 		}
 
 		// Remap image via AssetBuilder
-		remapped, err := b.AssetBuilder.RemapImage(container.Image)
-		if err != nil {
-			return nil, fmt.Errorf("unable to remap container image %q: %w", container.Image, err)
+		container.Image = b.AssetBuilder.RemapImage(container.Image)
+
+		if b.Cluster.HasImageVolumesSupport() {
+			for _, etcdVersion := range etcdSupportedVersions() {
+				volumeMount := v1.VolumeMount{
+					MountPath: "/opt/etcd-v" + etcdVersion.Version,
+				}
+				if etcdVersion.SymlinkToVersion == "" {
+					volumeMount.Name = "etcd-v" + strings.ReplaceAll(etcdVersion.Version, ".", "-")
+				} else {
+					volumeMount.Name = "etcd-v" + strings.ReplaceAll(etcdVersion.SymlinkToVersion, ".", "-")
+				}
+				container.VolumeMounts = append(container.VolumeMounts, volumeMount)
+			}
 		}
-		container.Image = remapped
 	}
 
 	var clientHost string
@@ -558,7 +579,7 @@ func (b *EtcdManagerBuilder) buildPod(etcdCluster kops.EtcdClusterSpec, instance
 	}
 
 	{
-		container.Command = exec.WithTee("/etcd-manager", args, "/var/log/etcd.log")
+		container.Command = exec.WithTee("/ko-app/etcd-manager", args, "/var/log/etcd.log")
 
 		cpuRequest := resource.MustParse("200m")
 		if etcdCluster.CPURequest != nil {
