@@ -124,30 +124,37 @@ func (b *KubeletOptionsBuilder) configureKubelet(cluster *kops.Cluster, kubelet
 
 	cloudProvider := cluster.GetCloudProvider()
 	klog.V(1).Infof("Cloud Provider: %s", cloudProvider)
-	if cloudProvider != kops.CloudProviderMetal {
-		if b.controlPlaneKubernetesVersion.IsLT("1.31") {
-			switch cloudProvider {
-			case kops.CloudProviderAWS:
-				kubelet.CloudProvider = "aws"
-			case kops.CloudProviderGCE:
-				kubelet.CloudProvider = "gce"
-			case kops.CloudProviderDO:
-				kubelet.CloudProvider = "external"
-			case kops.CloudProviderHetzner:
-				kubelet.CloudProvider = "external"
-			case kops.CloudProviderOpenstack:
-				kubelet.CloudProvider = "openstack"
-			case kops.CloudProviderAzure:
-				kubelet.CloudProvider = "azure"
-			case kops.CloudProviderScaleway:
-				kubelet.CloudProvider = "external"
-			default:
-				kubelet.CloudProvider = "external"
-			}
+	if b.controlPlaneKubernetesVersion.IsLT("1.31") {
+		switch cloudProvider {
+		case kops.CloudProviderAWS:
+			kubelet.CloudProvider = "aws"
+		case kops.CloudProviderGCE:
+			kubelet.CloudProvider = "gce"
+		case kops.CloudProviderDO:
+			kubelet.CloudProvider = "external"
+		case kops.CloudProviderHetzner:
+			kubelet.CloudProvider = "external"
+		case kops.CloudProviderOpenstack:
+			kubelet.CloudProvider = "openstack"
+		case kops.CloudProviderAzure:
+			kubelet.CloudProvider = "azure"
+		case kops.CloudProviderScaleway:
+			kubelet.CloudProvider = "external"
+		case kops.CloudProviderMetal:
+			kubelet.CloudProvider = ""
+		default:
+			kubelet.CloudProvider = "external"
+		}
 
-			if cluster.Spec.ExternalCloudControllerManager != nil {
-				kubelet.CloudProvider = "external"
-			}
+		if cluster.Spec.ExternalCloudControllerManager != nil {
+			kubelet.CloudProvider = "external"
+		}
+	} else {
+		if cloudProvider == kops.CloudProviderMetal {
+			// metal does not (yet) have a cloud-controller-manager, so we don't need to set the cloud-provider flag
+			// If we do set it to external, kubelet will taint the node with the node.kops.k8s.io/uninitialized taint
+			// and there is no cloud-controller-manager to remove it
+			kubelet.CloudProvider = ""
 		} else {
 			kubelet.CloudProvider = "external"
 		}
@@ -166,11 +173,7 @@ func (b *KubeletOptionsBuilder) configureKubelet(cluster *kops.Cluster, kubelet
 	// Prevent image GC from pruning the pause image
 	// https://github.com/kubernetes/enhancements/tree/master/keps/sig-node/2040-kubelet-cri#pinned-images
 	image := "registry.k8s.io/pause:3.9"
-	var err error
-	if image, err = b.AssetBuilder.RemapImage(image); err != nil {
-		return err
-	}
-	kubelet.PodInfraContainerImage = image
+	kubelet.PodInfraContainerImage = b.AssetBuilder.RemapImage(image)
 
 	if kubelet.FeatureGates == nil {
 		kubelet.FeatureGates = make(map[string]string)
@@ -180,16 +183,13 @@ func (b *KubeletOptionsBuilder) configureKubelet(cluster *kops.Cluster, kubelet
 		if _, found := kubelet.FeatureGates["InTreePluginAWSUnregister"]; !found && kubernetesVersion.IsLT("1.31") {
 			kubelet.FeatureGates["InTreePluginAWSUnregister"] = "true"
 		}
-
-		if _, found := kubelet.FeatureGates["CSIMigrationAWS"]; !found && kubernetesVersion.IsLT("1.27") {
-			kubelet.FeatureGates["CSIMigrationAWS"] = "true"
-		}
 	}
 
 	// Set systemd as the default cgroup driver for kubelet
-	if kubelet.CgroupDriver == "" {
-		kubelet.CgroupDriver = "systemd"
-	}
+	// In Kubernetes 1.34, with the KubeletCgroupDriverFromCRI feature gate enabled and a container runtime
+	// that supports the RuntimeConfig CRI RPC, the kubelet automatically detects the appropriate cgroup driver
+	// from the runtime, and ignores the cgroupDriver setting within the kubelet configuration.
+	kubelet.CgroupDriver = "systemd"
 
 	if kubelet.ProtectKernelDefaults == nil {
 		kubelet.ProtectKernelDefaults = fi.PtrTo(true)
