@@ -28,10 +28,10 @@ type NodeProblemDetectorOptionsBuilder struct {
 	*OptionsContext
 }
 
-var _ loader.OptionsBuilder = &NodeProblemDetectorOptionsBuilder{}
+var _ loader.ClusterOptionsBuilder = &NodeProblemDetectorOptionsBuilder{}
 
-func (b *NodeProblemDetectorOptionsBuilder) BuildOptions(o interface{}) error {
-	clusterSpec := o.(*kops.ClusterSpec)
+func (b *NodeProblemDetectorOptionsBuilder) BuildOptions(o *kops.Cluster) error {
+	clusterSpec := &o.Spec
 	if clusterSpec.NodeProblemDetector == nil {
 		return nil
 	}
@@ -51,11 +51,6 @@ func (b *NodeProblemDetectorOptionsBuilder) BuildOptions(o interface{}) error {
 		npd.MemoryRequest = &defaultMemoryRequest
 	}
 
-	if npd.CPULimit == nil {
-		defaultCPULimit := resource.MustParse("200m")
-		npd.CPULimit = &defaultCPULimit
-	}
-
 	if npd.MemoryLimit == nil {
 		defaultMemoryLimit := resource.MustParse("100Mi")
 		npd.MemoryLimit = &defaultMemoryLimit
