@@ -29,25 +29,25 @@ type NetworkModelBuilder struct {
 	Lifecycle fi.Lifecycle
 }
 
-var _ fi.ModelBuilder = &NetworkModelBuilder{}
+var _ fi.CloudupModelBuilder = &NetworkModelBuilder{}
 
-func (b *NetworkModelBuilder) Build(c *fi.ModelBuilderContext) error {
+func (b *NetworkModelBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 
-	ipRange := b.Cluster.Spec.NetworkCIDR
+	ipRange := b.Cluster.Spec.Networking.NetworkCIDR
 	if ipRange == "" {
 		// no cidr specified, use the default vpc in DO that's always available
 		return nil
 	}
 
-	clusterName := strings.Replace(b.ClusterName(), ".", "-", -1)
+	clusterName := strings.ReplaceAll(b.ClusterName(), ".", "-")
 	vpcName := "vpc-" + clusterName
 
 	// Create a separate vpc for this cluster.
 	vpc := &dotasks.VPC{
-		Name:      fi.String(vpcName),
-		Region:    fi.String(b.Cluster.Spec.Subnets[0].Region),
+		Name:      fi.PtrTo(vpcName),
+		Region:    fi.PtrTo(b.Cluster.Spec.Networking.Subnets[0].Region),
 		Lifecycle: b.Lifecycle,
-		IPRange:   fi.String(ipRange),
+		IPRange:   fi.PtrTo(ipRange),
 	}
 	c.AddTask(vpc)
 
