@@ -362,6 +362,10 @@ func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addECRPermissions(p)
 	}
 
+	if b.Cluster.Spec.Containerd != nil && b.Cluster.Spec.Containerd.UseECRCredentialsForMirrors {
+		addECRPullThroughPermissions(p)
+	}
+
 	if b.Cluster.Spec.Networking.AmazonVPC != nil {
 		addAmazonVPCCNIPermissions(p)
 	}
@@ -406,7 +410,7 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	if !b.UseServiceAccountExternalPermisssions {
 		esc := b.Cluster.Spec.SnapshotController != nil &&
 			fi.ValueOf(b.Cluster.Spec.SnapshotController.Enabled)
-		AddAWSEBSCSIDriverPermissions(p, esc)
+		AddAWSEBSCSIDriverPermissions(b, p, esc)
 
 		AddCCMPermissions(p, b.Cluster.Spec.Networking.Kubenet != nil)
 
@@ -430,6 +434,10 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addECRPermissions(p)
 	}
 
+	if b.Cluster.Spec.Containerd != nil && b.Cluster.Spec.Containerd.UseECRCredentialsForMirrors {
+		addECRPullThroughPermissions(p)
+	}
+
 	if b.Cluster.Spec.Networking.AmazonVPC != nil {
 		addAmazonVPCCNIPermissions(p)
 	}
@@ -465,6 +473,10 @@ func (r *NodeRoleNode) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 		addECRPermissions(p)
 	}
 
+	if b.Cluster.Spec.Containerd != nil && b.Cluster.Spec.Containerd.UseECRCredentialsForMirrors {
+		addECRPullThroughPermissions(p)
+	}
+
 	if b.Cluster.Spec.Networking.AmazonVPC != nil {
 		addAmazonVPCCNIPermissions(p)
 	}
@@ -776,6 +788,17 @@ func addECRPermissions(p *Policy) {
 	)
 }
 
+func addECRPullThroughPermissions(p *Policy) {
+	// Permissions needed for ECR pull-through cache functionality
+	// These permissions are only needed when UseECRCredentialsForMirrors is enabled
+	p.unconditionalAction.Insert(
+		"ecr:ReplicateImage",
+		"ecr:BatchImportUpstreamImage",
+		"ecr:CreateRepository",
+		"ecr:TagResource",
+	)
+}
+
 func addCalicoSrcDstCheckPermissions(p *Policy) {
 	p.unconditionalAction.Insert(
 		"ec2:DescribeInstances",
@@ -851,11 +874,13 @@ func AddCCMPermissions(p *Policy, cloudRoutes bool) {
 		"ec2:DescribeSecurityGroups",
 		"ec2:DescribeSubnets",
 		"ec2:DescribeVpcs",
+		"ec2:DescribeInstanceTopology",
 		"elasticloadbalancing:DescribeLoadBalancers",
 		"elasticloadbalancing:DescribeLoadBalancerAttributes",
 		"elasticloadbalancing:DescribeListeners",
 		"elasticloadbalancing:DescribeLoadBalancerPolicies",
 		"elasticloadbalancing:DescribeTargetGroups",
+		"elasticloadbalancing:DescribeTargetGroupAttributes",
 		"elasticloadbalancing:DescribeTargetHealth",
 		"iam:CreateServiceLinkedRole",
 		"kms:DescribeKey",
@@ -883,6 +908,7 @@ func AddCCMPermissions(p *Policy, cloudRoutes bool) {
 		"elasticloadbalancing:DeleteTargetGroup",
 		"elasticloadbalancing:ModifyListener",
 		"elasticloadbalancing:ModifyTargetGroup",
+		"elasticloadbalancing:ModifyTargetGroupAttributes",
 		"elasticloadbalancing:RegisterTargets",
 		"elasticloadbalancing:DeregisterTargets",
 		"elasticloadbalancing:SetLoadBalancerPoliciesOfListener",
@@ -928,8 +954,11 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy, enableWAF, enableWAFv2,
 		"ec2:DescribeVpcPeeringConnections",
 		"ec2:DescribeVpcs",
 		"ec2:DescribeAccountAttributes",
+		"ec2:GetSecurityGroupsForVpc",
 
+		"elasticloadbalancing:DescribeCapacityReservation",
 		"elasticloadbalancing:DescribeListeners",
+		"elasticloadbalancing:DescribeListenerAttributes",
 		"elasticloadbalancing:DescribeListenerCertificates",
 		"elasticloadbalancing:DescribeLoadBalancers",
 		"elasticloadbalancing:DescribeLoadBalancerAttributes",
@@ -938,6 +967,7 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy, enableWAF, enableWAFv2,
 		"elasticloadbalancing:DescribeTargetGroups",
 		"elasticloadbalancing:DescribeTargetGroupAttributes",
 		"elasticloadbalancing:DescribeTargetHealth",
+		"elasticloadbalancing:DescribeTrustStores",
 	)
 	if enableWAF {
 		p.unconditionalAction.Insert(
@@ -979,9 +1009,12 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy, enableWAF, enableWAFv2,
 		"elasticloadbalancing:DeleteRule",
 		"elasticloadbalancing:DeleteTargetGroup",
 		"elasticloadbalancing:DeregisterTargets",
+		"elasticloadbalancing:ModifyCapacityReservation",
 		"elasticloadbalancing:ModifyListener",
+		"elasticloadbalancing:ModifyListenerAttributes",
 		"elasticloadbalancing:ModifyLoadBalancerAttributes",
 		"elasticloadbalancing:ModifyRule",
+		"elasticloadbalancing:SetRulePriorities",
 		"elasticloadbalancing:ModifyTargetGroup",
 		"elasticloadbalancing:ModifyTargetGroupAttributes",
 		"elasticloadbalancing:RegisterTargets",
@@ -1030,11 +1063,11 @@ func AddClusterAutoscalerPermissions(p *Policy, useStaticInstanceList bool) {
 }
 
 // AddAWSEBSCSIDriverPermissions appens policy statements that the AWS EBS CSI Driver needs to operate.
-func AddAWSEBSCSIDriverPermissions(p *Policy, appendSnapshotPermissions bool) {
+func AddAWSEBSCSIDriverPermissions(b *PolicyBuilder, p *Policy, appendSnapshotPermissions bool) {
 	addKMSIAMPolicies(p)
 
 	if appendSnapshotPermissions {
-		addSnapshotPersmissions(p)
+		addSnapshotPersmissions(b, p)
 	}
 
 	p.unconditionalAction.Insert(
@@ -1064,7 +1097,7 @@ func AddAWSEBSCSIDriverPermissions(p *Policy, appendSnapshotPermissions bool) {
 	)
 }
 
-func addSnapshotPersmissions(p *Policy) {
+func addSnapshotPersmissions(b *PolicyBuilder, p *Policy) {
 	p.unconditionalAction.Insert(
 		"ec2:CreateSnapshot",
 		"ec2:DescribeAvailabilityZones",
@@ -1073,6 +1106,20 @@ func addSnapshotPersmissions(p *Policy) {
 	p.clusterTaggedAction.Insert(
 		"ec2:DeleteSnapshot",
 	)
+	p.Statement = append(p.Statement,
+		&Statement{
+			Effect: StatementEffectAllow,
+			Action: stringorset.Of(
+				"ec2:CreateVolume",
+			),
+			Resource: stringorset.Set([]string{fmt.Sprintf("arn:%v:ec2:*:*:snapshot/*", b.Partition)}),
+			Condition: Condition{
+				"StringEquals": map[string]string{
+					"aws:ResourceTag/KubernetesCluster": p.clusterName,
+				},
+			},
+		},
+	)
 }
 
 // AddDNSControllerPermissions adds IAM permissions used by the dns-controller.
@@ -1170,13 +1217,14 @@ func addCiliumEniPermissions(p *Policy) {
 		"ec2:UnassignPrivateIpAddresses",
 		"ec2:CreateNetworkInterface",
 		"ec2:DescribeNetworkInterfaces",
-		"ec2:DescribeVpcPeeringConnections",
 		"ec2:DescribeSecurityGroups",
-		"ec2:DetachNetworkInterface",
 		"ec2:DeleteNetworkInterface",
 		"ec2:ModifyNetworkInterfaceAttribute",
 		"ec2:DescribeVpcs",
 		"ec2:CreateTags",
+		"ec2:DescribeRouteTables",
+		"ec2:DescribeTags",
+		"ec2:DescribeInstances",
 	)
 }
 
