@@ -21,6 +21,7 @@ import (
 	"sort"
 	"strings"
 
+	armcompute "github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/compute/armcompute"
 	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
 	"github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"k8s.io/kops/pkg/apis/kops"
@@ -48,6 +49,7 @@ const (
 	DefaultAWSEtcdVolumeIonIops       = 100
 	DefaultAWSEtcdVolumeGp3Iops       = 3000
 	DefaultAWSEtcdVolumeGp3Throughput = 125
+	DefaultAZUREEtcdVolumeType        = "StandardSSD_LRS"
 	DefaultGCEEtcdVolumeType          = "pd-ssd"
 )
 
@@ -98,7 +100,7 @@ func (b *MasterVolumeBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			}
 			sort.Strings(allMembers)
 
-			switch b.Cluster.Spec.GetCloudProvider() {
+			switch b.Cluster.GetCloudProvider() {
 			case kops.CloudProviderAWS:
 				err = b.addAWSVolume(c, name, volumeSize, zone, etcd, m, allMembers)
 				if err != nil {
@@ -122,8 +124,12 @@ func (b *MasterVolumeBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 				}
 			case kops.CloudProviderScaleway:
 				b.addScalewayVolume(c, name, volumeSize, zone, etcd, m, allMembers)
+
+			case kops.CloudProviderMetal:
+				// Nothing special to do for Metal (yet)
+
 			default:
-				return fmt.Errorf("unknown cloudprovider %q", b.Cluster.Spec.GetCloudProvider())
+				return fmt.Errorf("unknown cloudprovider %q", b.Cluster.GetCloudProvider())
 			}
 		}
 	}
@@ -281,7 +287,7 @@ func (b *MasterVolumeBuilder) addGCEVolume(c *fi.CloudupModelBuilderContext, pre
 	tags[gce.GceLabelNameEtcdClusterPrefix+etcd.Name] = gce.EncodeGCELabel(clusterSpec)
 
 	// GCE disk names must match the following regular expression: '[a-z](?:[-a-z0-9]{0,61}[a-z0-9])?'
-	prefix = strings.Replace(prefix, ".", "-", -1)
+	prefix = strings.ReplaceAll(prefix, ".", "-")
 	if strings.IndexByte("0123456789-", prefix[0]) != -1 {
 		prefix = "d" + prefix
 	}
@@ -314,8 +320,6 @@ func (b *MasterVolumeBuilder) addHetznerVolume(c *fi.CloudupModelBuilderContext,
 		Labels:    tags,
 	}
 	c.AddTask(t)
-
-	return
 }
 
 func (b *MasterVolumeBuilder) addOpenstackVolume(c *fi.CloudupModelBuilderContext, name string, volumeSize int32, zone string, etcd kops.EtcdClusterSpec, m kops.EtcdMemberSpec, allMembers []string) error {
@@ -359,6 +363,10 @@ func (b *MasterVolumeBuilder) addAzureVolume(
 	m kops.EtcdMemberSpec,
 	allMembers []string,
 ) error {
+	volumeType := fi.ValueOf(m.VolumeType)
+	if volumeType == "" {
+		volumeType = DefaultAZUREEtcdVolumeType
+	}
 	// The tags are use by Protokube to mount the volume and use it for etcd.
 	tags := map[string]*string{
 		// This is the configuration of the etcd cluster.
@@ -390,9 +398,10 @@ func (b *MasterVolumeBuilder) addAzureVolume(
 		ResourceGroup: &azuretasks.ResourceGroup{
 			Name: fi.PtrTo(b.Cluster.AzureResourceGroupName()),
 		},
-		SizeGB: fi.PtrTo(volumeSize),
-		Tags:   tags,
-		Zones:  []*string{&zoneNumber},
+		SizeGB:     fi.PtrTo(volumeSize),
+		Tags:       tags,
+		VolumeType: fi.PtrTo(armcompute.DiskStorageAccountTypes(volumeType)),
+		Zones:      []*string{&zoneNumber},
 	}
 	c.AddTask(t)
 
@@ -419,6 +428,4 @@ func (b *MasterVolumeBuilder) addScalewayVolume(c *fi.CloudupModelBuilderContext
 		Type:      fi.PtrTo(string(instance.VolumeVolumeTypeBSSD)),
 	}
 	c.AddTask(t)
-
-	return
 }
