@@ -18,6 +18,7 @@ package scalewaymodel
 
 import (
 	"fmt"
+	"strings"
 
 	"github.com/scaleway/scaleway-sdk-go/scw"
 	"k8s.io/kops/pkg/model"
@@ -26,6 +27,11 @@ import (
 	"k8s.io/kops/upup/pkg/fi/cloudup/scalewaytasks"
 )
 
+var commercialTypesWithBlockStorageOnly = []string{"PRO", "PLAY", "ENT"}
+
+const defaultNodeRootVolumeSizeGB = 50
+const defaultControlPlaneRootVolumeSizeGB = 20
+
 // InstanceModelBuilder configures instances for the cluster
 type InstanceModelBuilder struct {
 	*ScwModelContext
@@ -75,6 +81,19 @@ func (b *InstanceModelBuilder) Build(c *fi.CloudupModelBuilderContext) error {
 			instance.Role = fi.PtrTo(scaleway.TagRoleWorker)
 		}
 
+		// If the instance's commercial type is one that has no local storage, we have to specify for the
+		// block storage volume a big enough size (default size is 10GB)
+		for _, commercialType := range commercialTypesWithBlockStorageOnly {
+			if strings.HasPrefix(ig.Spec.MachineType, commercialType) {
+				if ig.IsControlPlane() {
+					instance.VolumeSize = fi.PtrTo(defaultControlPlaneRootVolumeSizeGB)
+				} else {
+					instance.VolumeSize = fi.PtrTo(defaultNodeRootVolumeSizeGB)
+				}
+				break
+			}
+		}
+
 		c.AddTask(&instance)
 	}
 	return nil
