@@ -107,7 +107,7 @@ func BuildKubernetesFileAssets(ig model.InstanceGroup, assetBuilder *assets.Asse
 			case kops.CloudProviderAWS:
 				binaryLocation := ig.RawClusterSpec().CloudProvider.AWS.BinariesLocation
 				if binaryLocation == nil {
-					binaryLocation = fi.PtrTo("https://artifacts.k8s.io/binaries/cloud-provider-aws/v1.27.1")
+					binaryLocation = fi.PtrTo("https://artifacts.k8s.io/binaries/cloud-provider-aws/v1.31.7")
 				}
 
 				u, err := url.Parse(fmt.Sprintf("%s/linux/%s/ecr-credential-provider-linux-%s", *binaryLocation, arch, arch))
@@ -122,7 +122,7 @@ func BuildKubernetesFileAssets(ig model.InstanceGroup, assetBuilder *assets.Asse
 			}
 		}
 
-		{
+		if ig.InstallCNIAssets() {
 			cniAsset, err := wellknownassets.FindCNIAssets(ig, assetBuilder, arch)
 			if err != nil {
 				return nil, err
@@ -146,23 +146,25 @@ func BuildKubernetesFileAssets(ig model.InstanceGroup, assetBuilder *assets.Asse
 			if runcAsset != nil {
 				kubernetesAssets[arch] = append(kubernetesAssets[arch], assets.BuildMirroredAsset(runcAsset))
 			}
-			nerdctlAsset, err := wellknownassets.FindNerdctlAsset(ig, assetBuilder, arch)
-			if err != nil {
-				return nil, err
+			if ig.RawClusterSpec().Containerd.InstallNerdCtl {
+				nerdctlAsset, err := wellknownassets.FindNerdctlAsset(ig, assetBuilder, arch)
+				if err != nil {
+					return nil, err
+				}
+				if nerdctlAsset != nil {
+					kubernetesAssets[arch] = append(kubernetesAssets[arch], assets.BuildMirroredAsset(nerdctlAsset))
+				}
 			}
-			if nerdctlAsset != nil {
-				kubernetesAssets[arch] = append(kubernetesAssets[arch], assets.BuildMirroredAsset(nerdctlAsset))
+			if ig.RawClusterSpec().Containerd.InstallCriCtl {
+				crictlAsset, err := wellknownassets.FindCrictlAsset(ig, assetBuilder, arch)
+				if err != nil {
+					return nil, err
+				}
+				if crictlAsset != nil {
+					kubernetesAssets[arch] = append(kubernetesAssets[arch], assets.BuildMirroredAsset(crictlAsset))
+				}
 			}
 		}
-
-		crictlAsset, err := wellknownassets.FindCrictlAsset(ig, assetBuilder, arch)
-		if err != nil {
-			return nil, err
-		}
-		if crictlAsset != nil {
-			kubernetesAssets[arch] = append(kubernetesAssets[arch], assets.BuildMirroredAsset(crictlAsset))
-		}
-
 	}
 
 	return &KubernetesFileAssets{
