@@ -25,6 +25,11 @@ type Instance struct {
 	SSHUser          string   `json:"sshUser,omitempty"`
 }
 
+type LoadBalancer struct {
+	Name    string `json:"name,omitempty"`
+	DNSName string `json:"dnsName,omitempty"`
+}
+
 // Subnet is the type for an subnetwork in a dump
 type Subnet struct {
 	ID   string `json:"id,omitempty"`
@@ -38,8 +43,9 @@ type VPC struct {
 
 // Dump is the type for a dump result
 type Dump struct {
-	Resources []interface{} `json:"resources,omitempty"`
-	Instances []*Instance   `json:"instances,omitempty"`
-	Subnets   []*Subnet     `json:"subnets,omitempty"`
-	VPC       *VPC          `json:"vpc,omitempty"`
+	Resources     []interface{}   `json:"resources,omitempty"`
+	Instances     []*Instance     `json:"instances,omitempty"`
+	LoadBalancers []*LoadBalancer `json:"loadBalancers,omitempty"`
+	Subnets       []*Subnet       `json:"subnets,omitempty"`
+	VPC           *VPC            `json:"vpc,omitempty"`
 }
