@@ -36,8 +36,7 @@ func TestSerializeEmptyCluster(t *testing.T) {
 	yamlString := string(yaml)
 	expected := `apiVersion: kops.k8s.io/v1alpha3
 kind: Cluster
-metadata:
-  creationTimestamp: null
+metadata: {}
 spec:
   api: {}
   cloudProvider: {}
