@@ -31,6 +31,7 @@ import (
 
 	"k8s.io/klog/v2"
 	"k8s.io/kops/tests/e2e/kubetest2-kops/aws"
+	"k8s.io/kops/tests/e2e/kubetest2-kops/azure"
 	"k8s.io/kops/tests/e2e/kubetest2-kops/do"
 	"k8s.io/kops/tests/e2e/kubetest2-kops/gce"
 	"k8s.io/kops/tests/e2e/pkg/kops"
@@ -190,6 +191,12 @@ func (d *deployer) createCluster(zones []string, adminAccess string, yes bool) e
 		} else {
 			args = appendIfUnset(args, "--master-size", "c5.large")
 		}
+	case "azure":
+		// Ensure https://github.com/Azure/rg-cleanup deletes removes resources
+		args = appendIfUnset(args, "--cloud-labels", "creationTimestamp="+time.Now().Format(time.RFC3339))
+		// Use SKUs for which there is enough quota
+		args = appendIfUnset(args, "--control-plane-size", "Standard_D4s_v3")
+		args = appendIfUnset(args, "--node-size", "Standard_D2s_v3")
 	case "gce":
 		if isArm {
 			args = appendIfUnset(args, "--master-size", "t2a-standard-2")
@@ -346,6 +353,8 @@ func (d *deployer) zones() ([]string, error) {
 	switch d.CloudProvider {
 	case "aws":
 		return aws.RandomZones(d.ControlPlaneCount)
+	case "azure":
+		return azure.RandomZones(1)
 	case "gce":
 		return gce.RandomZones(1)
 	case "digitalocean":
